import React from "react";
import ReactDOMServer from "react-dom/server";
import { getNationalNumber, formatSeconds } from "./util";
import { DateTime } from "luxon";
import type { Contact } from "./types";
import type { StoredVoicemail, StoredRecording } from "knex/types/tables";

function fromName(vm: StoredVoicemail, contact?: Contact) {
  return contact?.name ?? vm.fromName ?? "unknown";
}

export function getTicketSubject(vm: StoredVoicemail, contact?: Contact) {
  const name = fromName(vm, contact);
  return `New Voicemail from ${getNationalNumber(vm.fromNumber)} (${name})`;
}

export function getTicketBody(
  vm: StoredVoicemail & StoredRecording,
  contact?: Contact
) {
  const name = fromName(vm, contact);

  return ReactDOMServer.renderToStaticMarkup(
    <div>
      <div>
        <b>Received:</b>{" "}
        {DateTime.fromISO(vm.received).toLocaleString(DateTime.DATETIME_MED)}
      </div>
      <div>
        <b>From:</b> {getNationalNumber(vm.fromNumber)} ({name})
      </div>
      <div>
        <b>To:</b> {getNationalNumber(vm.toNumber)}x{vm.extensionNumber} (
        {vm.extensionName})
      </div>
      <div>
        <b>Duration: </b> {formatSeconds(vm.duration)}
      </div>
      <br />
      <div>
        <span>
          <b>Transcription:</b>{" "}
          {vm.transcriptionStatus === "CompletedPartially" ? (
            <i>(partial)</i>
          ) : undefined}
        </span>
        <p>
          <i>
            {vm.transcription
              ? `"${vm.transcription}"`
              : vm.transcriptionStatus}
          </i>
        </p>
      </div>
    </div>
  );
}
